import request from '@/utils/request'

// 查询工单流程节点步骤权限列表
export function listWfProcessActivityAuth(query) {
  return request({
    url: '/system/wfProcessActivityAuth/list',
    method: 'get',
    params: query
  })
}

// 查询工单流程节点步骤权限详细
export function getWfProcessActivityAuth(processActivityAuthId) {
  return request({
    url: '/system/wfProcessActivityAuth/' + processActivityAuthId,
    method: 'get'
  })
}

// 新增工单流程节点步骤权限
export function addWfProcessActivityAuth(data) {
  return request({
    url: '/system/wfProcessActivityAuth',
    method: 'post',
    data: data
  })
}

// 修改工单流程节点步骤权限
export function updateWfProcessActivityAuth(data) {
  return request({
    url: '/system/wfProcessActivityAuth',
    method: 'put',
    data: data
  })
}

// 删除工单流程节点步骤权限
export function delWfProcessActivityAuth(processActivityAuthId) {
  return request({
    url: '/system/wfProcessActivityAuth/' + processActivityAuthId,
    method: 'delete'
  })
}

// 查询拥有权限的用户
export function selectUserAuth(query) {
  return request({
    url: '/system/wfProcessActivityAuth/selectUserAuth',
    method: 'get',
    params: query
  })
}
